@@ -8,10 +8,10 @@ from tqdm import tqdm
 import numpy as np
 from morphio import MorphioError, SomaType, set_maximum_warnings
 from morphio.mut import Morphology  # pylint: disable=import-error
-from neurom.check import neuron_checks as nc
+from neurom.check import morphology_checks as mc
 from neurom.check import CheckResult
 from neurom.apps.annotate import annotate
-from neurom import load_neuron
+from neurom import load_morphology
 
 L = logging.getLogger('neuror')
 _ZERO_LENGTH = 1e-4
@@ -100,7 +100,8 @@ def sanitize_all(input_folder, output_folder, nprocesses=1):
     if nprocesses == 1:
         results = map(func, morphologies)
     else:
-        results = Pool(nprocesses).imap_unordered(func, morphologies, chunksize=100)
+        with Pool(nprocesses) as pool:
+            results = list(pool.imap_unordered(func, morphologies, chunksize=100))
     errored_paths = list(filter(None, tqdm(results, total=len(morphologies))))
     if errored_paths:
         L.info('Files in error:')
@@ -122,7 +123,7 @@ def fix_non_zero_segments(neuron, zero_length=_ZERO_LENGTH):
         a fixed morphio.mut.Morphology
     '''
     neuron = Morphology(neuron)
-    to_be_deleted = list()
+    to_be_deleted = []
     for section in neuron.iter():
         points = section.points
         distances = np.linalg.norm(np.diff(points, axis=0), axis=1)
@@ -161,15 +162,15 @@ def annotate_neurolucida(morph_path, checkers=None):
     """
     if checkers is None:
         checkers = {
-            nc.has_no_fat_ends: {"name": "fat end", "label": "Circle3", "color": "Blue"},
-            partial(nc.has_no_jumps, axis="z"): {
+            mc.has_no_fat_ends: {"name": "fat end", "label": "Circle3", "color": "Blue"},
+            partial(mc.has_no_jumps, axis="z"): {
                 "name": "zjump",
                 "label": "Circle2",
                 "color": "Green",
             },
-            nc.has_no_narrow_start: {"name": "narrow start", "label": "Circle1", "color": "Blue"},
-            nc.has_no_dangling_branch: {"name": "dangling", "label": "Circle6", "color": "Magenta"},
-            nc.has_multifurcation: {
+            mc.has_no_narrow_start: {"name": "narrow start", "label": "Circle1", "color": "Blue"},
+            mc.has_no_dangling_branch: {"name": "dangling", "label": "Circle6", "color": "Magenta"},
+            mc.has_multifurcation: {
                 "name": "Multifurcation",
                 "label": "Circle8",
                 "color": "Yellow",
@@ -185,7 +186,7 @@ def annotate_neurolucida(morph_path, checkers=None):
             L.exception(e, exc_info=True)
             return CheckResult(True)
 
-    neuron = load_neuron(morph_path)
+    neuron = load_morphology(morph_path)
     results = [_try(checker, neuron) for checker in checkers]
     markers = [
         dict(setting, data=result.info)
@@ -212,8 +213,10 @@ def annotate_neurolucida_all(morph_paths, nprocesses=1):
         dict of dict of markers (morph_path as keys)
     """
     summaries, annotations, markers = {}, {}, {}
-    for morph_path, result in zip(
-        morph_paths, Pool(nprocesses).map(annotate_neurolucida, morph_paths)
-    ):
-        annotations[str(morph_path)], summaries[str(morph_path)], markers[str(morph_path)] = result
+    with Pool(nprocesses) as pool:
+        for morph_path, result in zip(
+            morph_paths, pool.map(annotate_neurolucida, morph_paths)
+        ):
+            morph_path = str(morph_path)
+            annotations[morph_path], summaries[morph_path], markers[morph_path] = result
     return annotations, summaries, markers
